@@ -339,11 +339,21 @@ class DataframeType(BaseType):
     
     @type_operator(FIELD_DATAFRAME)
     def less_than(self, other_value):
-        return ~self.greater_than_or_equal_to(other_value)
+        target = self.replace_prefix(other_value.get("target"))
+        value_is_literal = other_value.get("value_is_literal", False)
+        comparator = self.replace_prefix(other_value.get("comparator")) if not value_is_literal else other_value.get("comparator")
+        comparison_data = self.get_comparator_data(comparator, value_is_literal)
+        results = np.where(self.value[target] < comparison_data, True, False)
+        return pd.Series(results)
     
     @type_operator(FIELD_DATAFRAME)
     def less_than_or_equal_to(self, other_value):
-        return ~self.greater_than(other_value)
+        target = self.replace_prefix(other_value.get("target"))
+        value_is_literal = other_value.get("value_is_literal", False)
+        comparator = self.replace_prefix(other_value.get("comparator")) if not value_is_literal else other_value.get("comparator")
+        comparison_data = self.get_comparator_data(comparator, value_is_literal)
+        results = np.where(self.value[target] <= comparison_data, True, False)
+        return pd.Series(results)
     
     @type_operator(FIELD_DATAFRAME)
     def greater_than_or_equal_to(self, other_value):
